@@ -7,8 +7,6 @@ Created on MAY 21, 2018
 # 以下两个模块可以通过 pip install thrift 安装获得
 import pprint
 
-from sqlalchemy.dialects.mysql.base import colspecs
-from sqlalchemy.dialects.postgresql.base import colspecs
 from thrift.protocol import TBinaryProtocol
 from thrift.transport import THttpClient
 
